@@ -98,7 +98,8 @@ def download(package: str,
             from mmcv import Config
         except ImportError:
             raise ImportError(
-                'Please install mmengine to use the download command!')
+                'Please install mmengine to use the download command: '
+                '`mim install mmengine`.')
 
     for config in configs:
         click.echo(f'processing {config}...')
